﻿Imports System.Windows.Threading
Imports System.Windows.Media.Animation
Imports System.IO

Class MainWindow

    Private initMouseX As Double
    Private finalMouseX As Double
    Private x As Double
    Private newX As Double
    Private timer As DispatcherTimer
    Private anim As DoubleAnimationUsingKeyFrames
    
    Private Sub MainWindow_Initialized(ByVal sender As Object, ByVal e As System.EventArgs) Handles Me.Initialized
        timer = New DispatcherTimer
        anim = New DoubleAnimationUsingKeyFrames

        anim.Duration = TimeSpan.FromMilliseconds(1800)
        timer.Interval = New TimeSpan(0, 0, 0, 0, 1000)
        AddHandler timer.Tick, AddressOf timer_Tick
    End Sub

    Private Sub MainWindow_KeyUp(ByVal sender As Object, ByVal e As System.Windows.Input.KeyEventArgs) Handles Me.KeyUp
        ' Move MetroStackPanel so that the WrapPanel with the 
        ' required alphabetical group is displayed first.
        ShiftStackPanel(e.Key.ToString(), MetroStackPanel)
    End Sub

    Private Sub MainWindow_Loaded(ByVal sender As Object, ByVal e As System.Windows.RoutedEventArgs) Handles Me.Loaded
        Dim metro As New Metrolizer
        metro.DisplayTiles(MetroStackPanel)

        Dim path As String = My.Settings.SkinPath
        Dim newDictionary As New ResourceDictionary()
        newDictionary.Source = New Uri(path, UriKind.Relative)
        Me.Resources.MergedDictionaries.Clear()
        Me.Resources.MergedDictionaries.Add(newDictionary)
    End Sub

    Private Sub MainCanvas_PreviewMouseLeftButtonDown(ByVal sender As Object, ByVal e As System.Windows.Input.MouseButtonEventArgs) Handles MainCanvas.PreviewMouseLeftButtonDown
        initMouseX = e.GetPosition(MainCanvas).X
        x = Canvas.GetLeft(MetroStackPanel)
    End Sub

    Private Sub MainCanvas_PreviewMouseLeftButtonUp(ByVal sender As Object, ByVal e As System.Windows.Input.MouseButtonEventArgs) Handles MainCanvas.PreviewMouseLeftButtonUp
        finalMouseX = e.GetPosition(MainCanvas).X
        Dim diff As Double = Math.Abs(finalMouseX - initMouseX)

        ' Make sure the diff is substantial so that tiles 
        ' don't scroll on double-click.
        If (diff > 5) Then
            If (finalMouseX < initMouseX) Then
                newX = x - (diff * 2)
            ElseIf (finalMouseX > initMouseX) Then
                newX = x + (diff * 2)
            End If

            anim.KeyFrames.Add(New SplineDoubleKeyFrame(newX, _
                                                             KeyTime.FromTimeSpan(TimeSpan.FromSeconds(1)), _
                                                             New KeySpline(0.161, 0.079, 0.008, 1)))
            anim.FillBehavior = FillBehavior.HoldEnd
            MetroStackPanel.BeginAnimation(Canvas.LeftProperty, anim)
            anim.KeyFrames.Clear()
            timer.Start()
        End If
    End Sub

    ' Check whether the StackPanel is no longer in view and
    ' return it to a suitable postion.
    Private Sub timer_Tick(ByVal sender As Object, ByVal e As EventArgs)
        Dim mspWidth As Double = MetroStackPanel.ActualWidth

        If (newX > 200) Then
            anim.KeyFrames.Add(New SplineDoubleKeyFrame(45, _
                                                         KeyTime.FromTimeSpan(TimeSpan.FromSeconds(1)), _
                                                         New KeySpline(0.161, 0.079, 0.008, 1)))
            anim.FillBehavior = FillBehavior.HoldEnd
            MetroStackPanel.BeginAnimation(Canvas.LeftProperty, anim)
            anim.KeyFrames.Clear()
        ElseIf ((newX + mspWidth) < 500) Then
            Dim widthX As Double = 500 - (newX + mspWidth)
            Dim shiftX As Double = newX + widthX
            anim.KeyFrames.Add(New SplineDoubleKeyFrame(shiftX, _
                                                         KeyTime.FromTimeSpan(TimeSpan.FromSeconds(1)), _
                                                         New KeySpline(0.161, 0.079, 0.008, 1)))
            anim.FillBehavior = FillBehavior.HoldEnd
            MetroStackPanel.BeginAnimation(Canvas.LeftProperty, anim)
            anim.KeyFrames.Clear()
        End If
        timer.Stop()
    End Sub

    Private Sub RedSkinButton_Click(ByVal sender As Object, ByVal e As System.Windows.RoutedEventArgs) Handles RedSkinButton.Click
        ChangeSkin("RedSkin.xaml")
        SaveSkin("RedSkin.xaml")
    End Sub

    Private Sub BlueSkinButton_Click(ByVal sender As Object, ByVal e As System.Windows.RoutedEventArgs) Handles BlueSkinButton.Click
        ChangeSkin("BlueSkin.xaml")
        SaveSkin("BlueSkin.xaml")
    End Sub

    Private Sub GreenSkinButton_Click(ByVal sender As Object, ByVal e As System.Windows.RoutedEventArgs) Handles GreenSkinButton.Click
        ChangeSkin("GreenSkin.xaml")
        SaveSkin("GreenSkin.xaml")
    End Sub

    Private Sub PurpleSkinButton_Click(ByVal sender As Object, ByVal e As System.Windows.RoutedEventArgs) Handles PurpleSkinButton.Click
        ChangeSkin("PurpleSkin.xaml")
        SaveSkin("PurpleSkin.xaml")
    End Sub

    Private Sub ChangeSkin(ByVal path As String)
        Dim skinRD As New ResourceDictionary
        skinRD.Source = New Uri(path, UriKind.Relative)
        Me.Resources.MergedDictionaries.Clear()
        Me.Resources.MergedDictionaries.Add(skinRD)
    End Sub

    Private Sub SaveSkin(ByVal path As String)
        My.Settings.SkinPath = path
        My.Settings.Save()
    End Sub

    Private Sub MainBgrndRct_MouseLeftButtonDown(ByVal sender As Object, ByVal e As System.Windows.Input.MouseButtonEventArgs) Handles MainBgrndRct.MouseLeftButtonDown
        Me.DragMove()
    End Sub

    Private Sub MinimizeButton_Click(ByVal sender As Object, ByVal e As System.Windows.RoutedEventArgs) Handles MinimizeButton.Click
        Me.WindowState = Windows.WindowState.Minimized
    End Sub

    Private Sub CloseButton_Click(ByVal sender As Object, ByVal e As System.Windows.RoutedEventArgs) Handles CloseButton.Click
        Me.Close()
    End Sub
    
End Class
